function [W,n]=calc_width(list,yearpos,monthpos,daypos) 
% [W,n]=calc_width(list,yearpos,monthpos,daypos)
% width calculation of polygons
%
% Shapefiles need to be treated by the "MIZaggregation" module into ArcGIS
% where polygons are exztracted and pretreated: 
%   - polygons selection 
%   - polygons aggregation
%   - polygon aggregat combine with line of ice free water
%
% WARNING : width calculation is made only on the polygon that 
% have the highest latitude extend.
%
% INPUTS :                                                      examples
%   list      characters for shapefiles selection         '*Greenland_WA.shp'
%   yearpos   position of the year in the filename               1:4
%   monthpos  position of the month in the filename              5:6
%   daypos    position of the day in the filename                7:8
%
% OUTPUTS:
%   W         width results
%   n         date associated to the width
%
% Example:
% [MIZ_GRL,n_MIZ_GRL] = calc_width('*1200_Greenland_WA.shp',1:4,5:6,7:8);
%
%
% Other m-files required: bwmorph.m, bwdist.m (Image processing Toolbox)
% Subfunctions: none
% MAT-files required: none

% Author: Paul NICOT
% UQAR-ISMER
% email: paul_nicot@uqar.ca
% Website: http://www.ismer.ca
% August 2014; Last revision: 02-Feb-2015

%------------- BEGIN CODE --------------

% list shapefiles
listing = dir(char(list));

% for each shapefiles of the list
for i = 1:length(listing);
    
    shp = shaperead(listing(i).name,'UseGeoCoords',true);
    
    if isempty(shp) == 0;
        % determine number of polygons
        for j = 1:length(shp);
            shpLength(j) = length(shp(j).Lat);
    
             % Selection of the polygon that have the longest latitude
             % extend (calculation only on this unique polygon)
             for k = find(shpLength == max(shpLength));
                lat = shp(k).Lat;
                lon = shp(k).Lon;
            end
        end
        
        % number of cell for 1 degre (100 = 1/100 degre)
        gridDensity = 100;

        % Matrix creation that cover the polygon extend
        [inGrid, inRefVec] = vec2mtx(lat, lon, gridDensity);

        % Matrix filled with the value '3'
        inPt = round([[1 1], 3]);

        inGrid3 = encodem(inGrid, inPt,1);

        % Values 3 and 0 are swiched (solid polygon)
        inGrid3(inGrid3 == 3) = 2;
        inGrid3(inGrid3 == 0) = 3;
        inGrid3(inGrid3 == 2) = 0;

        % Squeleton of the polygon with the option "thin"(--» see bwmorp)
        skelMiz = bwmorph(inGrid3, 'thin', inf);

        % Calculus of the euclidian distance from the edge 
        distMiz = bwdist(~inGrid3);

        % Euclidian distance is attributed along the skeleton
        distFromEdge = distMiz .* single(skelMiz);

        % Remove the 1km width value (correspond to the ice free limit
        % interface added for the aggregat polygon 
        distFromEdge(distFromEdge==1) = 1 ./ 1000;
    
        %  Average width along the skeleton       
        width=mean(distFromEdge(distFromEdge~=0));
    
        % integration of width result into the structure
        [listing(i).width] = deal(width .* 2);
        
    else
        [listing(i).width] = 0;
    end
    
    % Date updating
    name = listing(i).name;
     
    [listing(i).date] = datenum(str2num(name(:,yearpos)), str2num(name(:,monthpos)), str2num(name(:,daypos)));
        
    
    clear shp shpLength k lat lon gridDensity inPt inGrid3 skeletonizedImage edtImage distFromEdge  name
end

W = [listing(:).width];
n = [listing(:).date];

%------------- END OF CODE --------------

        